Index
All Classes and Interfaces|All Packages|Serialized Form
A
- AbstractAgenticWorkflow<Request,
Response> - Class in com.javaaidev.agenticpatterns.core - AbstractAgenticWorkflow(String, ObservationRegistry) - Constructor for class com.javaaidev.agenticpatterns.core.AbstractAgenticWorkflow
- AbstractAgenticWorkflowBuilder<Request,
Response, - Class in com.javaaidev.agenticpatterns.coreT> - AbstractAgenticWorkflowBuilder() - Constructor for class com.javaaidev.agenticpatterns.core.AbstractAgenticWorkflowBuilder
- action - Variable in class com.javaaidev.agenticpatterns.core.CustomWorkflowBuilder
- action(Function<Request, Response>) - Method in class com.javaaidev.agenticpatterns.core.CustomWorkflowBuilder
-
Set the action of this workflow
- actualTypeArguments() - Method in record class com.javaaidev.agenticpatterns.core.ParameterizedTypeImpl
-
Returns the value of the
actualTypeArgumentsrecord component. - Agent - Class in com.javaaidev.agenticpatterns.core
-
An agent to execute tasks
- Agent(ChatClient) - Constructor for class com.javaaidev.agenticpatterns.core.Agent
- Agent(ChatClient, ObservationRegistry) - Constructor for class com.javaaidev.agenticpatterns.core.Agent
- AGENT_EXECUTION - Enum constant in enum class com.javaaidev.agenticpatterns.core.observation.AgentExecutionObservationDocumentation
- AGENT_EXECUTION_INPUT - Enum constant in enum class com.javaaidev.agenticpatterns.core.observation.AgentExecutionObservationDocumentation.HighCardinalityKeyNames
- AGENT_EXECUTION_OUTPUT - Enum constant in enum class com.javaaidev.agenticpatterns.core.observation.AgentExecutionObservationDocumentation.HighCardinalityKeyNames
- AGENT_NAME - Enum constant in enum class com.javaaidev.agenticpatterns.core.observation.AgentExecutionObservationDocumentation.LowCardinalityKeyNames
- AgentExecutionException - Exception Class in com.javaaidev.agenticpatterns.core
- AgentExecutionException(String) - Constructor for exception class com.javaaidev.agenticpatterns.core.AgentExecutionException
- AgentExecutionException(String, Throwable) - Constructor for exception class com.javaaidev.agenticpatterns.core.AgentExecutionException
- AgentExecutionObservationContext - Class in com.javaaidev.agenticpatterns.core.observation
- AgentExecutionObservationContext(String, Object) - Constructor for class com.javaaidev.agenticpatterns.core.observation.AgentExecutionObservationContext
- AgentExecutionObservationConvention - Interface in com.javaaidev.agenticpatterns.core.observation
- AgentExecutionObservationDocumentation - Enum Class in com.javaaidev.agenticpatterns.core.observation
- AgentExecutionObservationDocumentation.HighCardinalityKeyNames - Enum Class in com.javaaidev.agenticpatterns.core.observation
- AgentExecutionObservationDocumentation.LowCardinalityKeyNames - Enum Class in com.javaaidev.agenticpatterns.core.observation
- AgenticWorkflow<Request,
Response> - Interface in com.javaaidev.agenticpatterns.core -
Agentic workflow
- AgenticWorkflow.Builder<Request,
Response, - Interface in com.javaaidev.agenticpatterns.coreT> -
Builder to create AgenticWorkflow
- AgentUtils - Class in com.javaaidev.agenticpatterns.core
- AgentUtils() - Constructor for class com.javaaidev.agenticpatterns.core.AgentUtils
B
- build() - Method in interface com.javaaidev.agenticpatterns.core.AgenticWorkflow.Builder
- build() - Method in class com.javaaidev.agenticpatterns.core.CustomWorkflowBuilder
C
- chatClient - Variable in class com.javaaidev.agenticpatterns.core.Agent
- ChatModelCompletionContentObservationFilter - Class in com.javaaidev.agenticpatterns.core.observation
- ChatModelCompletionContentObservationFilter() - Constructor for class com.javaaidev.agenticpatterns.core.observation.ChatModelCompletionContentObservationFilter
- com.javaaidev.agenticpatterns.core - package com.javaaidev.agenticpatterns.core
- com.javaaidev.agenticpatterns.core.observation - package com.javaaidev.agenticpatterns.core.observation
- connections() - Method in record class com.javaaidev.agenticpatterns.core.McpClientConfiguration.SseClientProperties
-
Returns the value of the
connectionsrecord component. - connections() - Method in record class com.javaaidev.agenticpatterns.core.McpClientConfiguration.StdioClientProperties
-
Returns the value of the
connectionsrecord component. - connections() - Method in record class com.javaaidev.agenticpatterns.core.McpClientConfiguration.StreamableHttpClientProperties
-
Returns the value of the
connectionsrecord component. - custom() - Static method in interface com.javaaidev.agenticpatterns.core.AgenticWorkflow
- CustomWorkflowBuilder<Request,
Response> - Class in com.javaaidev.agenticpatterns.core -
Build a custom AgenticWorkflow
- CustomWorkflowBuilder() - Constructor for class com.javaaidev.agenticpatterns.core.CustomWorkflowBuilder
D
- DefaultAgentExecutionObservationConvention - Class in com.javaaidev.agenticpatterns.core.observation
- DefaultAgentExecutionObservationConvention() - Constructor for class com.javaaidev.agenticpatterns.core.observation.DefaultAgentExecutionObservationConvention
- DefaultWorkflowExecutionObservationConvention - Class in com.javaaidev.agenticpatterns.core.observation
- DefaultWorkflowExecutionObservationConvention() - Constructor for class com.javaaidev.agenticpatterns.core.observation.DefaultWorkflowExecutionObservationConvention
- doExecute(Request) - Method in class com.javaaidev.agenticpatterns.core.AbstractAgenticWorkflow
E
- equals(Object) - Method in record class com.javaaidev.agenticpatterns.core.McpClientConfiguration
-
Indicates whether some other object is "equal to" this one.
- equals(Object) - Method in record class com.javaaidev.agenticpatterns.core.McpClientConfiguration.SseClientProperties
-
Indicates whether some other object is "equal to" this one.
- equals(Object) - Method in record class com.javaaidev.agenticpatterns.core.McpClientConfiguration.StdioClientProperties
-
Indicates whether some other object is "equal to" this one.
- equals(Object) - Method in record class com.javaaidev.agenticpatterns.core.McpClientConfiguration.StreamableHttpClientProperties
-
Indicates whether some other object is "equal to" this one.
- equals(Object) - Method in record class com.javaaidev.agenticpatterns.core.ParameterizedTypeImpl
-
Indicates whether some other object is "equal to" this one.
- execute(Request) - Method in class com.javaaidev.agenticpatterns.core.AbstractAgenticWorkflow
- execute(Request) - Method in interface com.javaaidev.agenticpatterns.core.AgenticWorkflow
-
Execute this workflow
G
- getActualTypeArguments() - Method in record class com.javaaidev.agenticpatterns.core.ParameterizedTypeImpl
- getAgentName() - Method in class com.javaaidev.agenticpatterns.core.observation.AgentExecutionObservationContext
- getHighCardinalityKeyValues(AgentExecutionObservationContext) - Method in class com.javaaidev.agenticpatterns.core.observation.DefaultAgentExecutionObservationConvention
- getHighCardinalityKeyValues(WorkflowExecutionObservationContext) - Method in class com.javaaidev.agenticpatterns.core.observation.DefaultWorkflowExecutionObservationConvention
- getLowCardinalityKeyValues(AgentExecutionObservationContext) - Method in class com.javaaidev.agenticpatterns.core.observation.DefaultAgentExecutionObservationConvention
- getLowCardinalityKeyValues(WorkflowExecutionObservationContext) - Method in class com.javaaidev.agenticpatterns.core.observation.DefaultWorkflowExecutionObservationConvention
- getName() - Method in class com.javaaidev.agenticpatterns.core.AbstractAgenticWorkflow
- getName() - Method in class com.javaaidev.agenticpatterns.core.Agent
-
Name of this agent, for tracing purpose
- getName() - Method in interface com.javaaidev.agenticpatterns.core.AgenticWorkflow
-
Name of this workflow
- getName() - Method in class com.javaaidev.agenticpatterns.core.observation.DefaultAgentExecutionObservationConvention
- getName() - Method in class com.javaaidev.agenticpatterns.core.observation.DefaultWorkflowExecutionObservationConvention
- getOwnerType() - Method in record class com.javaaidev.agenticpatterns.core.ParameterizedTypeImpl
- getRawType() - Method in record class com.javaaidev.agenticpatterns.core.ParameterizedTypeImpl
- getWorkflowName() - Method in class com.javaaidev.agenticpatterns.core.observation.WorkflowExecutionObservationContext
H
- hashCode() - Method in record class com.javaaidev.agenticpatterns.core.McpClientConfiguration
-
Returns a hash code value for this object.
- hashCode() - Method in record class com.javaaidev.agenticpatterns.core.McpClientConfiguration.SseClientProperties
-
Returns a hash code value for this object.
- hashCode() - Method in record class com.javaaidev.agenticpatterns.core.McpClientConfiguration.StdioClientProperties
-
Returns a hash code value for this object.
- hashCode() - Method in record class com.javaaidev.agenticpatterns.core.McpClientConfiguration.StreamableHttpClientProperties
-
Returns a hash code value for this object.
- hashCode() - Method in record class com.javaaidev.agenticpatterns.core.ParameterizedTypeImpl
-
Returns a hash code value for this object.
L
- loadPromptTemplateFromClasspath(String) - Static method in class com.javaaidev.agenticpatterns.core.AgentUtils
-
Load prompt template from classpath by name
M
- map(Observation.Context) - Method in class com.javaaidev.agenticpatterns.core.observation.ChatModelCompletionContentObservationFilter
- McpClientConfiguration - Record Class in com.javaaidev.agenticpatterns.core
- McpClientConfiguration(McpClientConfiguration.StdioClientProperties, McpClientConfiguration.SseClientProperties, McpClientConfiguration.StreamableHttpClientProperties) - Constructor for record class com.javaaidev.agenticpatterns.core.McpClientConfiguration
-
Creates an instance of a
McpClientConfigurationrecord class. - McpClientConfiguration(McpClientConfiguration.SseClientProperties) - Constructor for record class com.javaaidev.agenticpatterns.core.McpClientConfiguration
- McpClientConfiguration(McpClientConfiguration.StdioClientProperties) - Constructor for record class com.javaaidev.agenticpatterns.core.McpClientConfiguration
- McpClientConfiguration(McpClientConfiguration.StreamableHttpClientProperties) - Constructor for record class com.javaaidev.agenticpatterns.core.McpClientConfiguration
- McpClientConfiguration.SseClientProperties - Record Class in com.javaaidev.agenticpatterns.core
- McpClientConfiguration.StdioClientProperties - Record Class in com.javaaidev.agenticpatterns.core
- McpClientConfiguration.StreamableHttpClientProperties - Record Class in com.javaaidev.agenticpatterns.core
- mergeMap(Map<String, Object>, Map<String, Object>) - Static method in class com.javaaidev.agenticpatterns.core.AgentUtils
-
Merge two maps into one map
N
- name - Variable in class com.javaaidev.agenticpatterns.core.AbstractAgenticWorkflow
- name - Variable in class com.javaaidev.agenticpatterns.core.AbstractAgenticWorkflowBuilder
- name(String) - Method in class com.javaaidev.agenticpatterns.core.AbstractAgenticWorkflowBuilder
- name(String) - Method in interface com.javaaidev.agenticpatterns.core.AgenticWorkflow.Builder
O
- objectToMap(Object) - Static method in class com.javaaidev.agenticpatterns.core.AgentUtils
-
Convert an object into a map using Jackson ObjectMapper
- observationRegistry - Variable in class com.javaaidev.agenticpatterns.core.AbstractAgenticWorkflow
- observationRegistry - Variable in class com.javaaidev.agenticpatterns.core.AbstractAgenticWorkflowBuilder
- observationRegistry - Variable in class com.javaaidev.agenticpatterns.core.Agent
- observationRegistry(ObservationRegistry) - Method in class com.javaaidev.agenticpatterns.core.AbstractAgenticWorkflowBuilder
- observationRegistry(ObservationRegistry) - Method in interface com.javaaidev.agenticpatterns.core.AgenticWorkflow.Builder
- ownerType() - Method in record class com.javaaidev.agenticpatterns.core.ParameterizedTypeImpl
-
Returns the value of the
ownerTyperecord component.
P
- ParameterizedTypeImpl - Record Class in com.javaaidev.agenticpatterns.core
- ParameterizedTypeImpl(Type, Type[], Type) - Constructor for record class com.javaaidev.agenticpatterns.core.ParameterizedTypeImpl
-
Creates an instance of a
ParameterizedTypeImplrecord class.
R
- rawType() - Method in record class com.javaaidev.agenticpatterns.core.ParameterizedTypeImpl
-
Returns the value of the
rawTyperecord component. - resolveType(Type, Class<?>, int) - Static method in class com.javaaidev.agenticpatterns.core.TypeResolver
S
- safeGet(T, Function<T, R>, R) - Static method in class com.javaaidev.agenticpatterns.core.AgentUtils
- self() - Method in class com.javaaidev.agenticpatterns.core.AbstractAgenticWorkflowBuilder
- sseClientProperties() - Method in record class com.javaaidev.agenticpatterns.core.McpClientConfiguration
-
Returns the value of the
sseClientPropertiesrecord component. - SseClientProperties(Map<String, McpSseClientProperties.SseParameters>) - Constructor for record class com.javaaidev.agenticpatterns.core.McpClientConfiguration.SseClientProperties
-
Creates an instance of a
SseClientPropertiesrecord class. - stdioClientProperties() - Method in record class com.javaaidev.agenticpatterns.core.McpClientConfiguration
-
Returns the value of the
stdioClientPropertiesrecord component. - StdioClientProperties(Map<String, McpStdioClientProperties.Parameters>) - Constructor for record class com.javaaidev.agenticpatterns.core.McpClientConfiguration.StdioClientProperties
-
Creates an instance of a
StdioClientPropertiesrecord class. - streamableHttpClientProperties() - Method in record class com.javaaidev.agenticpatterns.core.McpClientConfiguration
-
Returns the value of the
streamableHttpClientPropertiesrecord component. - StreamableHttpClientProperties(Map<String, McpStreamableHttpClientProperties.ConnectionParameters>) - Constructor for record class com.javaaidev.agenticpatterns.core.McpClientConfiguration.StreamableHttpClientProperties
-
Creates an instance of a
StreamableHttpClientPropertiesrecord class. - supportsContext(Observation.Context) - Method in interface com.javaaidev.agenticpatterns.core.observation.AgentExecutionObservationConvention
- supportsContext(Observation.Context) - Method in interface com.javaaidev.agenticpatterns.core.observation.WorkflowExecutionObservationConvention
T
- toJson(Object) - Static method in class com.javaaidev.agenticpatterns.core.AgentUtils
-
Get JSON content of an object
- toServerParameters() - Method in record class com.javaaidev.agenticpatterns.core.McpClientConfiguration.StdioClientProperties
- toString() - Method in record class com.javaaidev.agenticpatterns.core.McpClientConfiguration.SseClientProperties
-
Returns a string representation of this record class.
- toString() - Method in record class com.javaaidev.agenticpatterns.core.McpClientConfiguration.StdioClientProperties
-
Returns a string representation of this record class.
- toString() - Method in record class com.javaaidev.agenticpatterns.core.McpClientConfiguration.StreamableHttpClientProperties
-
Returns a string representation of this record class.
- toString() - Method in record class com.javaaidev.agenticpatterns.core.McpClientConfiguration
-
Returns a string representation of this record class.
- toString() - Method in record class com.javaaidev.agenticpatterns.core.ParameterizedTypeImpl
-
Returns a string representation of this record class.
- TypeResolver - Class in com.javaaidev.agenticpatterns.core
- TypeResolver() - Constructor for class com.javaaidev.agenticpatterns.core.TypeResolver
V
- valueOf(String) - Static method in enum class com.javaaidev.agenticpatterns.core.observation.AgentExecutionObservationDocumentation.HighCardinalityKeyNames
-
Returns the enum constant of this class with the specified name.
- valueOf(String) - Static method in enum class com.javaaidev.agenticpatterns.core.observation.AgentExecutionObservationDocumentation.LowCardinalityKeyNames
-
Returns the enum constant of this class with the specified name.
- valueOf(String) - Static method in enum class com.javaaidev.agenticpatterns.core.observation.AgentExecutionObservationDocumentation
-
Returns the enum constant of this class with the specified name.
- valueOf(String) - Static method in enum class com.javaaidev.agenticpatterns.core.observation.WorkflowExecutionObservationDocumentation.HighCardinalityKeyNames
-
Returns the enum constant of this class with the specified name.
- valueOf(String) - Static method in enum class com.javaaidev.agenticpatterns.core.observation.WorkflowExecutionObservationDocumentation.LowCardinalityKeyNames
-
Returns the enum constant of this class with the specified name.
- valueOf(String) - Static method in enum class com.javaaidev.agenticpatterns.core.observation.WorkflowExecutionObservationDocumentation
-
Returns the enum constant of this class with the specified name.
- values() - Static method in enum class com.javaaidev.agenticpatterns.core.observation.AgentExecutionObservationDocumentation.HighCardinalityKeyNames
-
Returns an array containing the constants of this enum class, in the order they are declared.
- values() - Static method in enum class com.javaaidev.agenticpatterns.core.observation.AgentExecutionObservationDocumentation.LowCardinalityKeyNames
-
Returns an array containing the constants of this enum class, in the order they are declared.
- values() - Static method in enum class com.javaaidev.agenticpatterns.core.observation.AgentExecutionObservationDocumentation
-
Returns an array containing the constants of this enum class, in the order they are declared.
- values() - Static method in enum class com.javaaidev.agenticpatterns.core.observation.WorkflowExecutionObservationDocumentation.HighCardinalityKeyNames
-
Returns an array containing the constants of this enum class, in the order they are declared.
- values() - Static method in enum class com.javaaidev.agenticpatterns.core.observation.WorkflowExecutionObservationDocumentation.LowCardinalityKeyNames
-
Returns an array containing the constants of this enum class, in the order they are declared.
- values() - Static method in enum class com.javaaidev.agenticpatterns.core.observation.WorkflowExecutionObservationDocumentation
-
Returns an array containing the constants of this enum class, in the order they are declared.
W
- WORKFLOW_EXECUTION - Enum constant in enum class com.javaaidev.agenticpatterns.core.observation.WorkflowExecutionObservationDocumentation
- WORKFLOW_EXECUTION_INPUT - Enum constant in enum class com.javaaidev.agenticpatterns.core.observation.WorkflowExecutionObservationDocumentation.HighCardinalityKeyNames
- WORKFLOW_EXECUTION_OUTPUT - Enum constant in enum class com.javaaidev.agenticpatterns.core.observation.WorkflowExecutionObservationDocumentation.HighCardinalityKeyNames
- WORKFLOW_NAME - Enum constant in enum class com.javaaidev.agenticpatterns.core.observation.WorkflowExecutionObservationDocumentation.LowCardinalityKeyNames
- WorkflowExecutionException - Exception Class in com.javaaidev.agenticpatterns.core
- WorkflowExecutionException(String) - Constructor for exception class com.javaaidev.agenticpatterns.core.WorkflowExecutionException
- WorkflowExecutionException(String, Throwable) - Constructor for exception class com.javaaidev.agenticpatterns.core.WorkflowExecutionException
- WorkflowExecutionObservationContext - Class in com.javaaidev.agenticpatterns.core.observation
- WorkflowExecutionObservationContext(String, Object) - Constructor for class com.javaaidev.agenticpatterns.core.observation.WorkflowExecutionObservationContext
- WorkflowExecutionObservationConvention - Interface in com.javaaidev.agenticpatterns.core.observation
- WorkflowExecutionObservationDocumentation - Enum Class in com.javaaidev.agenticpatterns.core.observation
- WorkflowExecutionObservationDocumentation.HighCardinalityKeyNames - Enum Class in com.javaaidev.agenticpatterns.core.observation
- WorkflowExecutionObservationDocumentation.LowCardinalityKeyNames - Enum Class in com.javaaidev.agenticpatterns.core.observation
All Classes and Interfaces|All Packages|Serialized Form